@@ -6,7 +6,7 @@ import unittest
 import yappi
 import _yappi
 import utils
-import multiprocessing  # added to fix http://bugs.python.org/issue15881 for > Py2.6
+import multiprocessing
 import subprocess
 
 _counter = 0
@@ -277,10 +277,10 @@ class BasicUsage(utils.YappiUnitTestCase):
     def test_profile_decorator(self):
 
         def aggregate(func, stats):
-            fname = "tests/%s.profile" % (func.__name__)
+            fname = f"tests/{func.__name__}.profile"
             try:
                 stats.add(fname)
-            except IOError:
+            except OSError:
                 pass
             stats.save(fname)
             raise Exception("messing around")
@@ -1191,7 +1191,7 @@ class MultithreadedScenarios(utils.YappiUnitTestCase):
         # TODO: I put dummy() to fix below, remove the comments after a while.
         self.assertTrue( # FIX: I see this fails sometimes?
             tsm is not None,
-            'Could not find "_MainThread". Found: %s' % (', '.join(utils.get_stat_names(tstats))))
+            f"Could not find \"_MainThread\". Found: {', '.join(utils.get_stat_names(tstats))}")
 
     def test_ctx_stats(self):
         from threading import Thread
@@ -1271,7 +1271,7 @@ class MultithreadedScenarios(utils.YappiUnitTestCase):
         # TODO: I put dummy() to fix below, remove the comments after a while.
         self.assertTrue( # FIX: I see this fails sometimes
             tsmain is not None,
-            'Could not find "_MainThread". Found: %s' % (', '.join(utils.get_stat_names(stats))))
+            f"Could not find \"_MainThread\". Found: {', '.join(utils.get_stat_names(stats))}")
         self.assertTrue(1.0 > tst2.ttot >= 0.5)
         self.assertTrue(1.0 > tst1.ttot >= 0.5)
 
@@ -1328,7 +1328,7 @@ class MultithreadedScenarios(utils.YappiUnitTestCase):
             ts = []
             for i in (0.01, 0.05, 0.1):
                 t = threading.Thread(target=burn_cpu, args=(i, ))
-                t.name = "burn_cpu-%s" % str(i)
+                t.name = f"burn_cpu-{str(i)}"
                 t.start()
                 ts.append(t)
             for t in ts:
@@ -1355,10 +1355,7 @@ class MultithreadedScenarios(utils.YappiUnitTestCase):
     def test_producer_consumer_with_queues(self):
         # we currently just stress yappi, no functionality test is done here.
         yappi.start()
-        if utils.is_py3x():
-            from queue import Queue
-        else:
-            from Queue import Queue
+        from queue import Queue
         from threading import Thread
         WORKER_THREAD_COUNT = 50
         WORK_ITEM_COUNT = 2000
@@ -1417,7 +1414,6 @@ class MultithreadedScenarios(utils.YappiUnitTestCase):
         fsh = utils.find_stat_by_name(stats, "handler")
         self.assertTrue(fsh is not None)
 
-    @unittest.skipIf(not sys.version_info >= (3, 2), "requires Python 3.2")
     def test_concurrent_futures(self):
         yappi.start()
         from concurrent.futures import ThreadPoolExecutor
@@ -1427,7 +1423,6 @@ class MultithreadedScenarios(utils.YappiUnitTestCase):
         time.sleep(1.0)
         yappi.stop()
 
-    @unittest.skipIf(not sys.version_info >= (3, 2), "requires Python 3.2")
     def test_barrier(self):
         yappi.start()
         b = threading.Barrier(2, timeout=1)
