@@ -13,6 +13,15 @@
 #error "Yappi requires long longs!"
 #endif
 
+#if PY_VERSION_HEX >= 0x030B0000  // Python 3.11+
+  #ifndef Py_BUILD_CORE
+    #define Py_BUILD_CORE
+  #endif
+  #include "internal/pycore_genobject.h"
+  #include "internal/pycore_frame.h"
+  #include "opcode.h"
+#endif
+
 #include "bytesobject.h"
 #include "frameobject.h"
 #include "callstack.h"
@@ -218,11 +227,14 @@ IS_SUSPENDED(PyFrameObject *frame) {
     if (gen == NULL) {
         return 0;
     }
-
-    // -1 is FRAME_SUSPENDED. See internal/pycore_frame.h
-    // TODO: Remove these after 3.12 make necessary public APIs.
-    // See https://discuss.python.org/t/python-3-11-frame-structure-and-various-changes/17895
-    return gen->gi_frame_state == -1;
+#if PY_MAJOR_VERSION >= 3 && PY_MINOR_VERSION == 14
+    unsigned char curr_op_code = (*frame->f_frame->instr_ptr).op.code;
+    return curr_op_code == YIELD_VALUE || curr_op_code == INSTRUMENTED_YIELD_VALUE;
+#elif PY_MAJOR_VERSION >= 3 && PY_MINOR_VERSION == 13
+    return FRAME_STATE_SUSPENDED(gen->gi_frame_state);
+#else
+    return gen->gi_frame_state == FRAME_SUSPENDED;
+#endif
 #elif PY_VERSION_HEX >= 0x030A0000 // Python 3.10+
     return (frame->f_state == FRAME_SUSPENDED);
 #else
